/*
 * DataTables4j, a JSP taglib to display table with jQuery and DataTables
 * Copyright (c) 2012, DataTables4j <datatables4j@gmail.com>
 *
 * This Program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License, version 2, as
 * published by the Free Software Foundation.
 * 
 * The Program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
package com.github.datatables4j.plugins.compression;

import java.io.IOException;
import java.io.StringReader;
import java.io.StringWriter;
import java.io.Writer;

import org.mozilla.javascript.EvaluatorException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.github.datatables4j.core.api.compressor.WebResourceCompressor;
import com.github.datatables4j.core.api.exception.CompressionException;
import com.yahoo.platform.yui.compressor.CssCompressor;
import com.yahoo.platform.yui.compressor.JavaScriptCompressor;

/**
 * Default compression class which uses YUICompressor.
 * 
 * @author Thibault Duchateau
 */
public class YuiResourceCompressor implements WebResourceCompressor {

	// Logger
	private static Logger logger = LoggerFactory.getLogger(YuiResourceCompressor.class);
		
	// Default options
	private static Options options = new Options();

	public String getCompressedJavascript(String input) throws CompressionException {
		
		Writer output = new StringWriter();
		JavaScriptCompressor compressor = null;
		
		try {
			compressor = new JavaScriptCompressor( new StringReader(input),
					new YuiCompressorErrorReporter());
			compressor.compress(output, options.lineBreakPos, options.munge, options.verbose, options.preserveAllSemiColons, options.disableOptimizations);
		} catch (EvaluatorException e) {
			logger.error("Unable to compress Javascript resource");
			throw new CompressionException(e);
		} catch (IOException e) {
			logger.error("Unable to compress Javascript resource");
			throw new CompressionException(e);
		}
		
		return output.toString();
	}
	
	public String getCompressedCss(String input) throws CompressionException{
		Writer output = new StringWriter();
		
		CssCompressor compressor;
		try {
			compressor = new CssCompressor(new StringReader(input));
			compressor.compress(output, options.lineBreakPos);
		} catch (IOException e) {
			logger.error("Unable to compress Css resource");
			throw new CompressionException(e);
		}
		
		return output.toString();
	}
}
